@@ -74,7 +74,15 @@ class FigManager:
             return key in self._map and not self.is_primary(key)
 
     def __init__(
-        self, name, parent, title, window_size, x, y, fig=None, subtitle=False,
+        self,
+        name,
+        parent,
+        title,
+        window_size,
+        x,
+        y,
+        fig=None,
+        subtitle=False,
     ):
         self.name = name
         self.parent = parent
@@ -120,7 +128,7 @@ class FigManager:
         _ = self.fig.canvas.mpl_connect("pick_event", self.onpick)
 
         self.help_text_box = None
-        self.showing_help = False
+        self.showing_help = 0
 
         self.msg_text_box = None
         self.msg_timer = None
@@ -158,7 +166,7 @@ class FigManager:
 
         self.key_presses["h"] = [
             lambda self, e: self.display_help(),
-            "Toggle this helpful information.",
+            "Cycle through the help pages.",
         ]
 
         self.key_presses["p"] = [
@@ -210,7 +218,8 @@ class FigManager:
 
             self.key_presses[f"{str(n+1)}"] = [
                 lambda self, e: self.parent.graph_by_overview_ordinal(
-                    int(e.key) - 1, use_progress_window=True,
+                    int(e.key) - 1,
+                    use_progress_window=True,
                 ),
                 f"Display the '{title}' graph in a separate window.",
             ]
@@ -349,30 +358,27 @@ class FigManager:
         if self.msg_text_box is not None:
             self.msg_text_box.set_visible(False)
 
+        self.showing_help = 0
         self.fig.canvas.draw()
 
     # -------------------------------------------------------------------------
     # Display info about using topplot. Mainly runtime keyboard options.
 
     def display_help(self):
-        if self.showing_help:
-            self.showing_help = False
-            if self.help_text_box is not None:
-                self.help_text_box.set_visible(False)
-                self.fig.canvas.draw()
-        else:
-            self.showing_help = True
-            if self.help_text_box is not None:
-                self.help_text_box.set_visible(True)
-            else:
+        def get_text(page):
+            txt = ""
+            if page == 1:
                 txt = "Key press menu:\n\n"
                 for (key, array) in self.key_presses.items():
                     item_text = array[1]
                     if item_text is not None:
                         txt += f"    '{key}' : {item_text}\n\n"
 
-                txt += """
-Graph legends:
+                txt += "#1: If the mouse pointer is over a graph, this applies to just that graph;"
+                txt += "    otherwise it applies to all the graphs in the active window."
+
+            elif page == 2:
+                txt = """Graph legends:
 
     Click on a legend line to hide it on the graph.
     Click on it again to display the line on the graph once more.
@@ -389,27 +395,46 @@ Graph legends:
                 if self.parent.mplcursors_present:
                     txt += """
 Annotations:
+
     Clicking on plotted lines will display information at that position. Right
-    click on the info to dispel it.
-"""
+    click on the info to dispel it."""
+            else:
+                return None
 
-                txt += f"""
-#1: If the mouse pointer is over a graph, this applies to just that graph;
-    otherwise it applies to all the graphs in the active window.
+            txt += f"""
 
-Version: {self.parent.config.version}            """
-                txt += "Copyright (c) 2019-2020 Jonathan Sambrook and Codethink Ltd."
+Page {page}   Version: {self.parent.config.version}    """
+            txt += "Copyright (c) 2019-2021 Jonathan Sambrook and Codethink Ltd."
+            return txt
 
-                bbox_props = dict(  # boxstyle='circle',
-                    pad=15, facecolor="white", alpha=0.975
-                )
+        # ----------------------------------------------------------------------
 
-                props = dict(fontfamily="monospace", fontsize=10, ha="left")
+        if self.help_text_box is None:
+            self.showing_help = 1
+            bbox_props = dict(  # boxstyle='circle',
+                pad=15, facecolor="white", alpha=0.975
+            )
 
-                self.help_text_box = self.fig.text(
-                    0.015, 0.03, txt, bbox=bbox_props, **props
-                )
-            self.fig.canvas.draw()
+            props = dict(fontfamily="monospace", fontsize=10, ha="left")
+
+            self.help_text_box = self.fig.text(
+                0.015, 0.03, get_text(1), bbox=bbox_props, **props
+            )
+        else:
+            next_page = self.showing_help + 1
+            txt = get_text(next_page)
+            if txt:
+                self.showing_help = next_page
+                if self.help_text_box is not None:
+                    self.help_text_box.set_text(txt)
+                    self.help_text_box.set_visible(True)
+
+            else:
+                self.showing_help = 0
+                if self.help_text_box is not None:
+                    self.help_text_box.set_visible(False)
+
+        self.fig.canvas.draw()
 
     # -------------------------------------------------------------------------
     # Hook for keypresses
@@ -580,7 +605,7 @@ Version: {self.parent.config.version}            """
 
         if not sys.platform.startswith("win"):
             # Necessary on my Linux WM, but not on Windows
-            window.iconify()
+            window.withdraw()
             window.deiconify()
 
         window.update_idletasks()
