@@ -28,6 +28,7 @@
 import math
 import re
 import sys
+from typing import Any, Dict, List, Tuple
 
 import matplotlib as mpl
 import matplotlib.dates as mdates
@@ -454,7 +455,7 @@ class Grapher:
     @staticmethod
     def generate_markeveries(
         row_count: int, col_count: int, total_markers: int
-    ) -> [(int, int)]:
+    ) -> List[Tuple[int, int]]:
         """Generate a list of (offset, markevery) tuples for a dataset of the given dimensions.
 
         Makes an attempt to avoid clustering markers on different lines.
@@ -506,6 +507,8 @@ class Grapher:
         force_single_core: bool = None,
         overview: bool = False,
     ):
+        ax_loadavg = None
+
         if force_single_core is None:
             ax_loadavg = ax_in
             ax_cpu = ax_loadavg.twinx()
@@ -552,7 +555,7 @@ class Grapher:
                     else [force_single_core]
                 ):
                     for measure in measures:
-                        extra_args = {}
+                        extra_args : Dict[str, Any] = {}
                         if force_single_core is None:
                             # The dollar symbols trigger lots of calling of
                             # expensive mathtext font functions
@@ -580,7 +583,9 @@ class Grapher:
                         colours.append(self.colours[measure])
 
                 df.plot(
-                    y=labels, color=colours, ax=ax_cpu,
+                    y=labels,
+                    color=colours,
+                    ax=ax_cpu,
                 )
         else:  # Single core (forced or natural)
             labels = []
@@ -591,7 +596,9 @@ class Grapher:
                 colours.append(self.colours[measure])
 
             df.plot(
-                y=labels, color=colours, ax=ax_cpu,
+                y=labels,
+                color=colours,
+                ax=ax_cpu,
             )
 
         # Legend(s)
@@ -624,7 +631,7 @@ class Grapher:
             self.single_legend(figman, title, legend_title, "cpu (%)", ax_cpu)
 
         # Axes fettling
-        if force_single_core is None:
+        if force_single_core is None and ax_loadavg:
             ax_loadavg.tick_params("x", which="minor", bottom=False)
             self.common_ax1(figman, ax_loadavg)
             ax_loadavg.set_ybound(lower=0, upper=df["load average"].max() * 105.0 / 100)
@@ -1055,7 +1062,12 @@ class Grapher:
 
         def generate_figman():
             return FigManager(
-                figman_name, self, self.title(title), self.window_size, 1, 1,
+                figman_name,
+                self,
+                self.title(title),
+                self.window_size,
+                1,
+                1,
             )
 
         self.dispense_graph(
@@ -1086,10 +1098,13 @@ class Grapher:
             max_timestamp = self.data.poi_df.tail(1).index[0]
 
             for core in range(self.cores):
-                x = int(core / sqrt)
-                y = core % sqrt
+                if self.cores < 3:
+                    ax = figman.plots[core]
+                else:
+                    x = int(core / sqrt)
+                    y = core % sqrt
 
-                ax = figman.plots[x][y]
+                    ax = figman.plots[x][y]
                 df = self.data.cpus_df.filter(regex=f"^cpu{core}")
 
                 self.graph_cpus(
@@ -1146,9 +1161,12 @@ class Grapher:
                 )
 
             for core in range(self.cores):
-                x = int(core / sqrt)
-                y = core % sqrt
-                ax = figman.plots[x][y]
+                if self.cores < 3:
+                    ax = figman.plots[core]
+                else:
+                    x = int(core / sqrt)
+                    y = core % sqrt
+                    ax = figman.plots[x][y]
                 self.graph_poi(
                     figman,
                     self.data.core_dfs[core],
@@ -1200,18 +1218,27 @@ class Grapher:
 
         def generate_figman():
             return FigManager(
-                figman_name, self, self.title(fig_title), self.window_size, 2, 2,
+                figman_name,
+                self,
+                self.title(fig_title),
+                self.window_size,
+                2,
+                2,
             )
 
         self.dispense_graph(
-            fig_title, figman_name, setup, generate_figman, use_progress_window,
+            fig_title,
+            figman_name,
+            setup,
+            generate_figman,
+            use_progress_window,
         )
 
     # -------------------------------------------------------------------------
     # Call specified method on all the figs, the specified one, or the most
     # recently created one.
 
-    def figs_foo(self, func, all_figs: bool, name: str):
+    def figs_foo(self, func, all_figs: bool, name: str = None):
         if self.fig_manager:
             figs = list(self.fig_manager.values())
             if name is not None:
@@ -1259,51 +1286,58 @@ class Grapher:
             }
 
         if len(self.config.which_graphs) > 0:
-            prev_figure_opened_okay = False
+            count = 0
 
             for c in self.config.which_graphs:
                 if c.isnumeric():
-                    prev_figure_opened_okay = True
                     i = int(c)
                     if i == 0:
                         self.graph_overview()
+                        count += 1
 
                     elif 1 <= i <= 4:
                         self.graph_by_overview_ordinal(i - 1)
+                        count += 1
 
                     else:
                         warn("'-g' takes numbers from 0 to 4.")
-                        prev_figure_opened_okay = False
 
                 elif c == "c":
-                    prev_figure_opened_okay = True
                     if self.cores > 1 and len(self.data.core_dfs) > 0:
                         self.graph_poi_per_cpu()
+                        count += 1
                     else:
                         warn("No multi-core data available to plot POI by CPU core.")
-                        prev_figure_opened_okay = False
 
                 elif c == "C":
-                    prev_figure_opened_okay = True
                     if self.cores > 1:
                         self.graph_cpu_per_cpu()
+                        count += 1
                     else:
                         warn("No multi-core data available to plot CPU data by core.")
-                        prev_figure_opened_okay = False
 
                 elif c == "p":
-                    if prev_figure_opened_okay:
+                    if count > 0:
                         self.save_figs(all_figs=False)
 
                 elif c == "P":
-                    self.save_figs()
+                    if count > 0:
+                        self.save_figs()
 
                 elif c == "q":
-                    if prev_figure_opened_okay:
+                    if count > 0:
                         self.close_figs(all_figs=False)
+                        if count > 1:
+                            count -= 1
+                        else:
+                            break
+                    else:
+                        break
 
                 elif c == "Q":
-                    self.close_figs()
+                    if count > 0:
+                        self.close_figs()
+                    break
 
                 else:
                     die(f"The character '{c}' doesn't represent a graph.")
